BigIntExportBehavior

Enum BigIntExportBehavior 

pub enum BigIntExportBehavior {
    String,
    Number,
    BigInt,
    Fail,
}
Allows you to configure how Specta’s Typescript exporter will deal with BigInt types (i64, i128 etc).

WARNING: None of these settings affect how your data is actually ser/deserialized. It’s up to you to adjust your ser/deserialize settings.

Variants



String

Export BigInt as a Typescript string

Doing this in serde is pretty simple.



Number

Export BigInt as a Typescript number.

WARNING: JSON.parse in JS will truncate your number resulting in data loss so ensure your deserializer supports large numbers.



BigInt

Export BigInt as a Typescript BigInt.

You must ensure you deserializer is able to support this.



Fail

Abort the export with an error.

This is the default behavior because without integration from your serializer and deserializer we can’t guarantee data loss won’t occur.