Layout

Enum Layout 

pub enum Layout {
    Namespaces,
    Files,
    ModulePrefixedName,
    FlatFile,
}
Allows configuring the format of the final types file

Variants



Namespaces

Produce a Typescript namespace for each Rust module



Files

Produce a dedicated file for each Rust module



ModulePrefixedName

Include the full module path in the types name but keep a flat structure.



FlatFile

Flatten all of the types into a single file of types. This mode doesn’t support having multiple types with the same name.