define

Function define 

pub fn define(raw: impl Into<Cow<'static, str>>) -> Reference
Define a custom Typescript string which can be used as a DataType::Reference.

This is an advanced feature which should be used with caution.