Module primitives

Module primitives 

Primitives provide building blocks for Specta-based libraries.

These are for advanced usecases, you should generally use [Typescript] or [JSDoc] in end-user applications.

Functions

export
Generate a group of export Type = ... Typescript string for a specific NamedDataType.
inline
Generate an inlined Typescript string for a specific DataType.
reference
Generate an Typescript string to refer to a specific DataType.