BrandedTypeExporter

Struct BrandedTypeExporter 

pub struct BrandedTypeExporter<'a> {
    pub types: &'a TypeCollection,
    /* private fields */
}
Reference to Typescript language exporter for branded type callbacks.

Fields

types: &'a TypeCollection

Collected types currently being exported.

Implementations

Methods from Deref<Target = Exporter>

pub fn export(&self, types: &TypeCollection) -> Result<String, Error>

Export the files into a single string.

Note: This returns an error if the format is Format::Files.

pub fn export_to( &self, path: impl AsRef<Path>, types: &TypeCollection, ) -> Result<(), Error>

Export the types to a specific file/folder.

When configured when format is Format::Files, you must provide a directory path. Otherwise, you must provide the path of a single file.