FrameworkExporter

Struct FrameworkExporter 

pub struct FrameworkExporter<'a> {
    pub types: &'a TypeCollection,
    /* private fields */
}
Reference to Typescript language exporter for framework

Fields

types: &'a TypeCollection

Collected types currently being exported.

Implementations

Source

impl FrameworkExporter<'_>

pub fn render_types(&mut self) -> Result<Cow<'static, str>, Error>

Render the types within the TypeCollection.

This will only work if used within [Self::framework_runtime] function. It allows frameworks to intersperse their user types into their runtime code.

pub fn inline(&self, dt: &DataType) -> Result<String, Error>

pub fn reference(&self, r: &Reference) -> Result<String, Error>

pub fn export<'a>( &self, ndts: impl Iterator<Item = &'a NamedDataType>, indent: &'a str, ) -> Result<String, Error>

Methods from Deref<Target = Exporter>

pub fn export(&self, types: &TypeCollection) -> Result<String, Error>

Export the files into a single string.

Note: This returns an error if the format is Format::Files.

pub fn export_to( &self, path: impl AsRef<Path>, types: &TypeCollection, ) -> Result<(), Error>

Export the types to a specific file/folder.

When configured when format is Format::Files, you must provide a directory path. Otherwise, you must provide the path of a single file.