Typescript

Struct Typescript 

#[non_exhaustive]
pub struct Typescript(/* private fields */);
JSDoc language exporter.

Implementations

Source

impl Typescript

pub fn new() -> Self

Construct a new JSDoc exporter with the default options configured.

pub fn header(self, header: impl Into<Cow<'static, str>>) -> Self

Configure a header for the file.

This is perfect for configuring lint ignore rules or other file-level comments.

pub fn bigint(self, bigint: BigIntExportBehavior) -> Self

Configure the BigInt handling behaviour

pub fn layout(self, layout: Layout) -> Self

Configure the layout of the generated file

pub fn branded_type_impl( self, builder: impl for<'a> Fn(BrandedTypeExporter<'a>, &Branded) -> Result<Cow<'static, str>, Error> + Send + Sync + 'static, ) -> Self

Configure how specta_typescript::branded! types are rendered.

See Exporter::branded_type_impl for details.

pub fn with_serde(self, mode: SerdeMode) -> Self

Configure the exporter to use specta-serde with the specified mode

pub fn with_serde_serialize(self) -> Self

Configure the exporter to export the types for #[derive(serde::Serialize)]

pub fn with_serde_deserialize(self) -> Self

Configure the exporter to export the types for #[derive(serde::Deserialize)]

pub fn export(&self, types: &TypeCollection) -> Result<String, Error>

Export the files into a single string.

Note: This returns an error if the format is Format::Files.

pub fn export_to( &self, path: impl AsRef<Path>, types: &TypeCollection, ) -> Result<(), Error>

Export the types to a specific file/folder.

When configured when format is Format::Files, you must provide a directory path. Otherwise, you must provide the path of a single file.