pub fn inline(
exporter: &dyn AsRef<Exporter>,
types: &TypeCollection,
dt: &DataType,
) -> Result<String, Error>Expand description
Generate an inlined Typescript string for a specific DataType.
This methods leaves all the same things as the export method up to the user.
Note that calling this method with a tagged struct or enum may cause the tag to not be exported.
The type should be wrapped in a NamedDataType to provide a proper name.