Function reference
Source pub fn reference(
exporter: &dyn AsRef<Exporter>,
types: &TypeCollection,
r: &Reference,
) -> Result<String, Error>
Generate an Typescript string to refer to a specific DataType.
For primitives this will include the literal type but for named type it will contain a reference.
See export for the list of things to consider when using this.