#[non_exhaustive]pub struct Typescript(/* private fields */);Expand description
JSDoc language exporter.
Implementations
Sourceimpl Typescript
impl Typescript
Sourcepub fn header(self, header: impl Into<Cow<'static, str>>) -> Self
pub fn header(self, header: impl Into<Cow<'static, str>>) -> Self
Configure a header for the file.
This is perfect for configuring lint ignore rules or other file-level comments.
Sourcepub fn bigint(self, bigint: BigIntExportBehavior) -> Self
pub fn bigint(self, bigint: BigIntExportBehavior) -> Self
Configure the BigInt handling behaviour
Sourcepub fn branded_type_impl(
self,
builder: impl for<'a> Fn(BrandedTypeExporter<'a>, &Branded) -> Result<Cow<'static, str>, Error> + Send + Sync + 'static,
) -> Self
pub fn branded_type_impl( self, builder: impl for<'a> Fn(BrandedTypeExporter<'a>, &Branded) -> Result<Cow<'static, str>, Error> + Send + Sync + 'static, ) -> Self
Configure how specta_typescript::branded! types are rendered.
See Exporter::branded_type_impl for details.
Sourcepub fn with_serde(self, mode: SerdeMode) -> Self
pub fn with_serde(self, mode: SerdeMode) -> Self
Configure the exporter to use specta-serde with the specified mode
Sourcepub fn with_serde_serialize(self) -> Self
pub fn with_serde_serialize(self) -> Self
Configure the exporter to export the types for #[derive(serde::Serialize)]
Sourcepub fn with_serde_deserialize(self) -> Self
pub fn with_serde_deserialize(self) -> Self
Configure the exporter to export the types for #[derive(serde::Deserialize)]